use svg_filters::{
    types::nodes::{primitives::color_matrix::ColorMatrixType, standard_input::StandardInput},
    Edge, Filter, Node,
};

fn main() {
    let mut filter = Filter::new();

    // <filter id="chromabb" >
    //   <feColorMatrix values="1 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 0 1 0" in="SourceGraphic" />
    //   <feOffset dx="25" dy="0" />
    //   <feGaussianBlur stdDeviation="5 0" result="red" />

    //   <feColorMatrix values="0 0 0 0 0 0 1 0 0 0 0 0 0 0 0 0 0 0 1 0" result="grn" in="SourceGraphic" />

    //   <feColorMatrix values="0 0 0 0 0 0 0 0 0 0 0 0 1 0 0 0 0 0 1 0" in="SourceGraphic" />
    //   <feOffset dx="-25" dy="0" />
    //   <feGaussianBlur stdDeviation="5 0" result="blu"/>

    //   <feComposite in="red" in2="blu" operator="arithmetic" k2="1" k3="1" result="rb" />
    //   <feComposite in="rb" in2="grn" operator="arithmetic" k2="1" k3="1" />
    // </filter>

    let chan_r = filter.add_node(Node::color_matrix(ColorMatrixType::Matrix(Box::new([
        1., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 1., 0.,
    ]))));
    let chan_g = filter.add_node(Node::color_matrix(ColorMatrixType::Matrix(Box::new([
        0., 0., 0., 0., 0., 0., 1., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 1., 0.,
    ]))));
    let chan_b = filter.add_node(Node::color_matrix(ColorMatrixType::Matrix(Box::new([
        0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 0., 1., 0., 0., 0., 0., 0., 1., 0.,
    ]))));

    let offset_r = filter.add_node(Node::offset(25., 0.));
    let offset_b = filter.add_node(Node::offset(-25., 0.));
    let blur_r = filter.add_node(Node::gaussian_blur_xy(5, 0));
    let blur_b = filter.add_node(Node::gaussian_blur_xy(5, 0));

    let composite_rb = filter.add_node(Node::composite_arithmetic(0., 1., 1., 0.));
    let composite_final = filter.add_node(Node::composite_arithmetic(0., 1., 1., 0.));

    filter.graph.extend_with_edges(&[
        (filter.source_graphic(), chan_r, Edge::unnamed()),
        (filter.source_graphic(), chan_b, Edge::unnamed()),
        (filter.source_graphic(), chan_g, Edge::unnamed()),
        (chan_r, offset_r, Edge::new("ro")),
        (offset_r, blur_r, Edge::new("rob")),
        (chan_b, offset_b, Edge::new("bo")),
        (offset_b, blur_b, Edge::new("bob")),
        (blur_r, composite_rb, Edge::new("robc").with_idx(0)),
        (blur_b, composite_rb, Edge::new("bobc").with_idx(1)),
        (composite_rb, composite_final, Edge::new("cf").with_idx(0)),
        (chan_g, composite_final, Edge::new("gf").with_idx(1)),
    ]);

    println!("{}", filter.to_svg())
}
